@@ -1411,6 +1411,30 @@ class MyStatsView(LoginRequiredMixin, TemplateView):
                 'item': "total length of exposed film in your collection",
                 'value': str(round((Negative.objects.filter(owner=self.request.user).aggregate(totallength=Sum('film__camera__cameramodel__negative_size__width'))['totallength'] or 0.00)/1000 )) + 'm',
             },
+            {
+                'image': "svg/percent.svg",
+                'url': reverse('schema:camera-list'),
+                'item': "percentage of camera models you've owned",
+                'value': str(round(100*(int(Camera.objects.filter(owner=self.request.user).values('cameramodel').distinct().count())/int(CameraModel.objects.count())))) + '%',
+            },
+            {
+                'image': "svg/percent.svg",
+                'url': reverse('schema:camera-list'),
+                'item': "percentage of lens models you've owned",
+                'value': str(round(100*(int(Lens.objects.filter(owner=self.request.user).values('lensmodel').distinct().count())/int(LensModel.objects.count())))) + '%',
+            },
+            {
+                'image': "svg/ownership.svg",
+                'url': reverse('schema:camera-list'),
+                'item': "net spent on cameras",
+                'value': str(round(((Camera.objects.filter(owner=self.request.user).aggregate(diff=(Sum('cost') - Sum('lost_price')))['diff'] or 0)), 2)),
+            },
+            {
+                'image': "svg/ownership.svg",
+                'url': reverse('schema:lens-list'),
+                'item': "net spent on lenses",
+                'value': str(round(((Lens.objects.filter(owner=self.request.user).aggregate(diff=(Sum('cost') - Sum('lost_price')))['diff'] or 0)), 2)),
+            }
         ]
 
         context['stats'] = stats
